| | |
|-|-|
| Software | ![Python](https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54) ![Qt](https://img.shields.io/badge/Qt-%23217346.svg?style=for-the-badge&logo=Qt&logoColor=white) ![PyTorch](https://img.shields.io/badge/PyTorch-%23EE4C2C.svg?style=for-the-badge&logo=PyTorch&logoColor=white) ![OpenCV](https://img.shields.io/badge/opencv-%23white.svg?style=for-the-badge&logo=opencv&logoColor=white) |
| Download | [![PyPI version](https://badge.fury.io/py/IQM-Vis.svg)](https://badge.fury.io/py/IQM-Vis) [![PyPI download month](https://img.shields.io/pypi/dm/IQM-Vis.svg)](https://pypi.python.org/pypi/IQM-Vis/) |
| Documentation | [![Generic badge](https://img.shields.io/badge/DOCS-Read-blue.svg)](https://mattclifford1.github.io/IQM-Vis/) |     
| Installation | [![Generic badge](https://img.shields.io/badge/INSTALL-View-green.svg)](https://mattclifford1.github.io/IQM-Vis/getting_started.html) | 
| Tutorials | [![Generic badge](https://img.shields.io/badge/TUTORIALS-View-blue.svg)](https://mattclifford1.github.io/IQM-Vis/Tutorials.html) | 
| Demos | [![Generic badge](https://img.shields.io/badge/HuggingFaceSpace-Launch-red.svg)](https://huggingface.co/spaces/mattclifford1/IQM-VIS) |



# IQM-Vis
Image Quality Metric Visualision. An extendable user interface for the assessment of transformations on image metrics.

Head over to the [DOCUMENTATION](https://mattclifford1.github.io/IQM-Vis/) for tutorials and package reference.

### IQM's average sensitivity to tranforms
![Alt text](https://github.com/mattclifford1/IQM-Vis/blob/main/pics/data_graphs.gif?raw=true "Dataset UI") 

### IQM's sensitivity to tranforms specific parameters
![Alt text](https://github.com/mattclifford1/IQM-Vis/blob/main/pics/params.gif?raw=true "Dataset UI") 

### IQM's correlation to human scores
![Alt text](https://github.com/mattclifford1/IQM-Vis/blob/main/pics/correlation.gif?raw=true "Dataset UI") 


